*****
GHOST
*****
-----------

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. image:: https://img.shields.io/pypi/dm/astro-ghost
   :target: https://pypi.org/project/astro-ghost/
   :alt: PyPI

.. image:: https://img.shields.io/readthedocs/uiucsnastro-ghost
   :target: https://uiucsnastro-ghost.readthedocs.io/en/latest/
   :alt: Read the Docs

"At the last dim horizon, we search among ghostly errors of observations for
landmarks that are scarcely more substantial. The search will continue. The
urge is older than history. It is not satisfied and it will not be oppressed."
--Edwin Hubble

Welcome to GHOST, the database for supernovae and their host galaxies. This
database contains ~16k sources in PS1, which were used to predict supernova
classes in Gagliano et al. (2020). Installation instructions for the analysis
tools are below.

Installation
------------

For details on installing and using GHOST, see the
`documentation <https://uiucsnastro-ghost.readthedocs.io/en/latest/>`_.


Citation
------------
If you use this code, please cite the associated paper with the bibtex entry below::

   @ARTICLE{2021ApJ...908..170G,
       author = {{Gagliano}, Alex and {Narayan}, Gautham and {Engel}, Andrew and {Carrasco Kind}, Matias and {LSST Dark Energy Science Collaboration}},
       title = "{GHOST: Using Only Host Galaxy Information to Accurately Associate and Distinguish Supernovae}",
       journal = {\apj},
       year = 2021,
       month = feb,
       volume = {908},
       number = {2},
       eid = {170},
       pages = {170},
       doi = {10.3847/1538-4357/abd02b},
       archivePrefix = {arXiv},
       eprint = {2008.09630},
       primaryClass = {astro-ph.GA},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2021ApJ...908..170G},
       adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

License
-------

This project is Copyright (c) Alexander Gagliano and licensed under
the terms of the BSD 3-Clause license. This package is based upon
the `Astropy package template <https://github.com/astropy/package-template>`_
which is licensed under the BSD 3-clause license. See the licenses folder for
more information.


Contributing
------------

We love contributions! astro_ghost is open source,
built on open source, and we'd love to have you hang out in our community.

**Imposter syndrome disclaimer**: We want your help. No, really.

There may be a little voice inside your head that is telling you that you're not
ready to be an open source contributor; that your skills aren't nearly good
enough to contribute. What could you possibly offer a project like this one?

We assure you - the little voice in your head is wrong. If you can write code at
all, you can contribute code to open source. Contributing to open source
projects is a fantastic way to advance one's coding skills. Writing perfect code
isn't the measure of a good developer (that would disqualify all of us!); it's
trying to create something, making mistakes, and learning from those
mistakes. That's how we all improve, and we are happy to help others learn.

Note: This disclaimer was originally written by
`Adrienne Lowe <https://github.com/adriennefriend>`_ for a
`PyCon talk <https://www.youtube.com/watch?v=6Uj746j9Heo>`_, and was adapted by
astro_ghost based on its use in the README file for the
`MetPy project <https://github.com/Unidata/MetPy>`_.
